module c4
(
    // Core Board
    input           CLOCK_50,
    input   [1:0]   KEY,
    output  [1:0]   LED,

    // Адаптер VGA 16 BIT
    output  [4:0]   VGA_R,
    output  [5:0]   VGA_G,
    output  [4:0]   VGA_B,
    output          VGA_HS,
    output          VGA_VS,

    // Кнопки, индикаторы дочерней платы
    input   [4:0]   DB_KEY,
    output  [4:0]   DB_LED,
    output  [7:0]   SEMI,
    output  [2:0]   SEN,

    // SDRAM 32 MB
    output  [12:0]  DRAM_A,         // Address
    output  [ 1:0]  DRAM_B,         // Bank
    inout   [15:0]  DRAM_D,         // Data
    output          DRAM_CS,        // Chip Select
    output          DRAM_CKE,       // Clock Enable
    output          DRAM_CLK,       // DRAM Clock
    output          DRAM_LDQM,      // Low Data Mask
    output          DRAM_HDQM,      // High Data Mask
    output          DRAM_CAS,       // Column Access
    output          DRAM_RAS,       // Row Access
    output          DRAM_WE,        // Write Enable

    // Относительно чипа CYCLONE
    output          TX,
    input           RX
);

assign LED          = 2'b11;        // Основная
assign DB_LED       = 5'b11111;     // Дочерняя
assign SEN          = 3'b000;       // Все выключены
assign SEMI         = 8'b11111111;  // Семисегментный

// SDRAM Configuration
assign DRAM_D       = 16'hz;
assign DRAM_CKE     = 1'b0;     // 1=Enable [0=Disable]
assign DRAM_CS      = 1'b1;     // 0=Enable [1=Disable]
assign DRAM_LDQM    = 1'b1;     // Disable
assign DRAM_HDQM    = 1'b1;     // Disable
assign DRAM_CAS     = 1'b1;     // NOP
assign DRAM_RAS     = 1'b1;
assign DRAM_WE      = 1'b1;

// Генератор частот
// --------------------------------------------------------------

wire locked;
wire clock_25;
wire clock_50;
wire clock_100;

pll PLL0
(
    .clock      (CLOCK_50),
    .clock_25   (clock_25),
    .clock_50   (clock_50),
    .clock_100  (clock_100),
    .locked     (locked)
);

// Видеогенератор
// ---------------------------------------------------------------------

vcard V1
(
    .clock  (clock_25),
    .r      (VGA_R[4:1]),
    .g      (VGA_G[5:2]),
    .b      (VGA_B[4:1]),
    .hs     (VGA_HS),
    .vs     (VGA_VS)
);

endmodule