module vcard
(
    input               clock,
    output  reg  [3:0]  r,
    output  reg  [3:0]  g,
    output  reg  [3:0]  b,
    output              hs,
    output              vs
);

// ---------------------------------------------------------------------
// Тайминги для горизонтальной и вертикальной развертки
parameter
//  Visible     Front       Sync        Back        Whole
    hzb = 48,   hzv = 640,  hzf = 16,   hzs = 96,   hzw = 800,
    vtb = 35,   vtv = 400,  vtf = 12,   vts = 2,    vtw = 449;
// ---------------------------------------------------------------------
assign hs = X <  (hzb + hzv + hzf);
assign vs = Y >= (vtb + vtv + vtf);
// ---------------------------------------------------------------------
// Позиция луча в кадре и максимальные позиции (x,y)
reg  [ 9:0] X = 0; wire xmax = (X == hzw - 1);
reg  [ 9:0] Y = 0; wire ymax = (Y == vtw - 1);
wire [ 9:0] x = (X - hzb);
wire [ 9:0] y = (Y - vtb);
// ---------------------------------------------------------------------

always @(posedge clock) begin

    // Черный цвет по краям
    {r, b, g} <= 12'h000;

    // Кадровая развертка
    X <= xmax ?         0 : X + 1;
    Y <= xmax ? (ymax ? 0 : Y + 1) : Y;

    // Вывод окна видеоадаптера
    if (X >= hzb && X < hzb + hzv && Y >= vtb && Y < vtb + vtv)
    begin
        {r, g, b} <= x[3:0] == 0 || y[3:0] == 0 ? 12'hFFF : {x[4]^y[4], 3'h0, x[5]^y[5], 3'h0, x[6]^y[6], 3'h0};
    end

end

endmodule